# Esbonio

Esbonio - to explain.

**This package is in early development**

A Python package that provides a number of Sphinx extensions and a [Language Server](https://microsoft.github.io/language-server-protocol/) for enhancing
the editing experience of `*.rst` files in editors.

## Installation

```
$ pip install esbonio
```
